@@ -127,8 +127,14 @@ QVariant CatalogTreeModel::headerData(int section, Qt::Orientation /*orientation
             return i18nc("@title:column", "Notes");
         case CatalogModelColumns::Context:
             return i18nc("@title:column", "Context");
+        case CatalogModelColumns::Files:
+            return i18nc("@title:column", "Files");
         case CatalogModelColumns::TranslationStatus:
             return i18nc("@title:column", "Translation Status");
+        case CatalogModelColumns::SourceLength:
+            return i18nc("@title:column Length of the original text", "Source length");
+        case CatalogModelColumns::TargetLength:
+            return i18nc("@title:column Length of the text in target language", "Target length");
         default:
             return {};
     }
@@ -233,6 +239,12 @@ QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
         }
         case CatalogModelColumns::Context:
             return m_catalog->context(index.row());
+        case CatalogModelColumns::Files:
+            return m_catalog->sourceFiles(index.row()).join('|');
+        case CatalogModelColumns::SourceLength:
+          return m_catalog->msgidWithPlurals(index.row(), true).length();
+        case CatalogModelColumns::TargetLength:
+          return m_catalog->msgstrWithPlurals(index.row(), true).length();
         default:
             return {};
     }
