@@ -504,7 +504,7 @@ FileSearchTab::FileSearchTab(QWidget *parent)
 
 
 //BEGIN resizeColumnToContents
-    static const int maxInitialWidths[] = {QApplication::desktop()->availableGeometry().width() / 3, QApplication::desktop()->availableGeometry().width() / 3};
+    static const int maxInitialWidths[] = {QGuiApplication::primaryScreen()->availableGeometry().width() / 3, QGuiApplication::primaryScreen()->availableGeometry().width() / 3};
     int column = sizeof(maxInitialWidths) / sizeof(int);
     while (--column >= 0)
         view->setColumnWidth(column, maxInitialWidths[column]);
@@ -612,7 +612,7 @@ void FileSearchTab::stopSearch()
 #if QT_VERSION >= 0x050500
     int i = m_runningJobs.size();
     while (--i >= 0)
-        QThreadPool::globalInstance()->cancel(m_runningJobs.at(i));
+        QThreadPool::globalInstance()->tryTake(m_runningJobs.at(i));
 #endif
     m_runningJobs.clear();
 }
