@@ -135,21 +135,21 @@ int displayNotes(QTextBrowser* browser, const QVector< Note >& notes, int active
         int i = 0;
         foreach (const Note& note, notes) {
             if (!note.from.isEmpty())
-                t.insertHtml(QStringLiteral("<i>") % note.from % QStringLiteral(":</i> "));
+                t.insertHtml(QStringLiteral("<i>") + note.from + QStringLiteral(":</i> "));
 
             if (i == active)
                 realOffset = t.position();
             QString content = escapeWithLinks(note.content);
             if (!multiple && content.contains('\n')) content += '\n';
             content.replace('\n', BR);
-            content += QString(QStringLiteral(" (<a href=\"note:/%1\">")).arg(i) % i18nc("link to edit note", "edit...") % QStringLiteral("</a>)<br />");
+            content += QString(QStringLiteral(" (<a href=\"note:/%1\">")).arg(i) + i18nc("link to edit note", "edit...") + QStringLiteral("</a>)<br />");
             t.insertHtml(content);
             i++;
         }
         if (multiple)
-            t.insertHtml(QStringLiteral("<a href=\"note:/add\">") % i18nc("link to add a note", "Add...") % QStringLiteral("</a> "));
+            t.insertHtml(QStringLiteral("<a href=\"note:/add\">") + i18nc("link to add a note", "Add...") + QStringLiteral("</a> "));
     } else
-        browser->insertHtml(QStringLiteral("<a href=\"note:/add\">") % i18nc("link to add a note", "Add a note...") % QStringLiteral("</a> "));
+        browser->insertHtml(QStringLiteral("<a href=\"note:/add\">") + i18nc("link to add a note", "Add a note...") + QStringLiteral("</a> "));
 
     return realOffset;
 }
